==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/RoleBindingRestrictionSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RoleBindingRestrictionSpecBuilder extends io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluentImpl<io.fabric8.openshift.api.model.RoleBindingRestrictionSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RoleBindingRestrictionSpec,io.fabric8.openshift.api.model.RoleBindingRestrictionSpecBuilder>{
  public RoleBindingRestrictionSpecBuilder() {
    this(false);
  }
  public RoleBindingRestrictionSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new RoleBindingRestrictionSpec(), validationEnabled);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RoleBindingRestrictionSpec(), validationEnabled);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent,io.fabric8.openshift.api.model.RoleBindingRestrictionSpec instance) {
    this(fluent, instance, false);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent,io.fabric8.openshift.api.model.RoleBindingRestrictionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGrouprestriction(instance.getGrouprestriction()); 
    fluent.withServiceaccountrestriction(instance.getServiceaccountrestriction()); 
    fluent.withUserrestriction(instance.getUserrestriction()); 
    this.validationEnabled = validationEnabled; 
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpec instance) {
    this(instance,false);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGrouprestriction(instance.getGrouprestriction()); 
    this.withServiceaccountrestriction(instance.getServiceaccountrestriction()); 
    this.withUserrestriction(instance.getUserrestriction()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RoleBindingRestrictionSpec build() {
    RoleBindingRestrictionSpec buildable = new RoleBindingRestrictionSpec(fluent.getGrouprestriction(),fluent.getServiceaccountrestriction(),fluent.getUserrestriction());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RoleBindingRestrictionSpecBuilder that = (RoleBindingRestrictionSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.4-sources.jar: io/fabric8/openshift/api/model/RoleBindingRestrictionSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RoleBindingRestrictionSpecBuilder extends io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluentImpl<io.fabric8.openshift.api.model.RoleBindingRestrictionSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.RoleBindingRestrictionSpec,io.fabric8.openshift.api.model.RoleBindingRestrictionSpecBuilder>{
  public RoleBindingRestrictionSpecBuilder() {
    this(false);
  }
  public RoleBindingRestrictionSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new RoleBindingRestrictionSpec(), validationEnabled);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RoleBindingRestrictionSpec(), validationEnabled);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent,io.fabric8.openshift.api.model.RoleBindingRestrictionSpec instance) {
    this(fluent, instance, false);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent,io.fabric8.openshift.api.model.RoleBindingRestrictionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGrouprestriction(instance.getGrouprestriction()); 
    fluent.withServiceaccountrestriction(instance.getServiceaccountrestriction()); 
    fluent.withUserrestriction(instance.getUserrestriction()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpec instance) {
    this(instance,false);
  }
  public RoleBindingRestrictionSpecBuilder(io.fabric8.openshift.api.model.RoleBindingRestrictionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGrouprestriction(instance.getGrouprestriction()); 
    this.withServiceaccountrestriction(instance.getServiceaccountrestriction()); 
    this.withUserrestriction(instance.getUserrestriction()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.RoleBindingRestrictionSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.RoleBindingRestrictionSpec build() {
    RoleBindingRestrictionSpec buildable = new RoleBindingRestrictionSpec(fluent.getGrouprestriction(),fluent.getServiceaccountrestriction(),fluent.getUserrestriction());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RoleBindingRestrictionSpecBuilder that = (RoleBindingRestrictionSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
